<?php
/*
Plugin Name: HubSpot for WordPress
Plugin URI: http://www.hubspot.com/
Description: This plugin makes it simple to add HubSpot Tracking Code to your WordPress CMS.
Author: HubSpot Version by Brian Whalley (bwhalley@hubspot.com)
Version: 0.5
Requires at least: 2.7
Author URI: http://www.hubspot.com
License: GPL

*/
	
// Where do I live?
function hsapp_plugin_path() {
	return plugins_url('', __FILE__).'/';
}

/*
 * User Interface
 */

if ( ! class_exists( 'HS_Admin' ) ) {

	require_once('hs_plugin_tools.php');
	
	class HS_Admin extends HS_Plugin_Admin {

		var $hook 		= 'hubspot-for-wordpress';
		var $filename	= 'hubspot-for-wordpress/hsanalytics.php';
		var $longname	= 'HubSpot Configuration';
		var $shortname	= 'HubSpot';
		var $optionname = 'HubSpotAnalyticsPP';
		var $homepage	= 'http://success.hubspot.com/';
		

		function HS_Admin() {
			add_action( 'admin_menu', array(&$this, 'register_settings_page') );
			add_filter( 'plugin_action_links', array(&$this, 'add_action_link'), 10, 2 );
			add_filter( 'ozh_adminmenu_icon', array(&$this, 'add_ozh_adminmenu_icon' ) );				
			
			add_action('admin_print_scripts', array(&$this,'config_page_scripts'));
			add_action('admin_print_styles', array(&$this,'config_page_styles'));	
			
			// add_action('wp_dashboard_setup', array(&$this,'widget_setup'));	
			add_action('admin_head', array(&$this,'config_page_head'));
		}
		
		function config_page_head() {
			if ($_GET['page'] == $this->hook) {
				wp_enqueue_script('jquery');
			?>
				 <script type="text/javascript" charset="utf-8">
				 	jQuery(document).ready(function(){
						jQuery('#explanation td').css("display","none");

						jQuery('#explain').click(function(){
							if ((jQuery('#explanation').css("display")) == "block")  {
								jQuery('#explanation').css("display","none");
							} else {
								jQuery('#explanation').css("display","block");
							}
						});
					});
				 </script>
			<?php
			}
		}
				
		function checkbox($id) {
			$options = get_option($this->optionname);
			return '<input type="checkbox" id="'.$id.'" name="'.$id.'"'. checked($options[$id],true,false).'/>';
		}

		function textinput($id) {
			$options = get_option($this->optionname);
			return '<input type="text" id="'.$id.'" name="'.$id.'" size="30" value="'.$options[$id].'"/>';
		}
		
		function config_page() {
			$options = get_option('HubSpotAnalyticsPP');

			if ( (isset($_POST['reset']) && $_POST['reset'] == "true") || !is_array($options) ) {
				$this->set_defaults();
				echo "<div class=\"updated\"><p>HubSpot Analytics settings reset to default.</p></div>\n";
			}

			if ( isset($_POST['submit']) ) {
				if (!current_user_can('manage_options')) die(__('You cannot edit the HubSpot Analytics for WordPress options.'));
				check_admin_referer('analyticspp-config');
				
				foreach (array('portal', 'appdomain') as $option_name) {
					if (isset($_POST[$option_name]))
						$options[$option_name] = $_POST[$option_name];
					else
						$options[$option_name] = '';
				}
				

				update_option('HubSpotAnalyticsPP', $options);
				echo "<div id=\"updatemessage\" class=\"updated fade\"><p>HubSpot Analytics settings updated.</p></div>\n";
				echo "<script type=\"text/javascript\">setTimeout(function(){jQuery('#updatemessage').hide('slow');}, 3000);</script>";	
			}

			
			?>
			<div class="wrap">
				<h2>HubSpot Configuration</h2>
				<div class="postbox-container" style="width:70%;">
					<div class="metabox-holder">	
						<div class="meta-box-sortables">
							<form action="" method="post" id="analytics-conf">
								<?php
									wp_nonce_field('analyticspp-config');
									$rows = array();
									$rows[] = array(
										'id' => 'portal',
										'label' => 'HubSpot Portal #',
										'content' => '<input id="portal" name="portal" type="text" size="20" maxlength="40" value="'.$options['portal'].'"/><br/>'

									);
									$rows[] = array(
										'id' => 'appdomain',
										'label' => 'HubSpot Application Domain',
										'desc' => '<a href="#" id="explain">Where do I get this?</a>',
										'content' => '<input id="appdomain" name="appdomain" type="text" size="30" maxlength="40" value="'.$options['appdomain'].'"/><br/><div id="explanation" style="background: #fff; border: 1px solid #ccc; padding: 5px; display:none;">
											<strong>Explanation</strong><br/>
											Find your HubSpot Portal Number and Application domain, a number with between 2 and 6 digits, and a string of text that ends in hubspot.com, as shown below:<br/>
											<br/>
											<img src="'.hsapp_plugin_path().'/ExternalSiteTrafficLogging.png" alt="portal ID"/><br/>
											<br/>
											Once you have entered your portal number and application domai in the box above your pages will be trackable by HubSpot Analytics.
										</div>'
									);
									$this->postbox('hssettings','HubSpot Analytics Settings',$this->form_table($rows));
								
									$rows = array();
									
								
								?>
						<div class="submit"><input type="submit" class="button-primary" name="submit" value="Update HubSpot Analytics Settings &raquo;" /></div>
					</form>
					<form action="" method="post">
						<input type="hidden" name="reset" value="true"/>
						<div class="submit"><input type="submit" value="Reset Default Settings &raquo;" /></div>
					</form>
				</div>
			</div>
		</div>
		<div class="postbox-container" style="width:20%;">
			<div class="metabox-holder">	
				<div class="meta-box-sortables">
					<?php
						$this->get_support();
					?>
				</div>
				<br/><br/><br/>
			</div>
		</div>
	</div>
			<?php
			if (isset($options['portal'])) {
				if ($options['portal'] == "") {
					add_action('admin_footer', array(&$this,'warning'));
				} else {
					if (isset($_POST['submit'])) {
						if ($_POST['portal'] != $options['portal'] ) {
							add_action('admin_footer', array(&$this,'success'));
						}
					}
				}
			} else {
				add_action('admin_footer', array(&$this,'warning'));
			}
		} 
		
		function set_defaults() {
			$options = get_option('HubSpotAnalyticsPP');
			$options['portal'] = '00';
			$options['appdomain'] = 'example.app7.hubspot.com';				
			update_option('HubSpotAnalyticsPP',$options);
		}
		
		function warning() {
			echo "<div id='message' class='error'><p><strong>HubSpot Analytics is not active.</strong> You must <a href='options-general.php?page=hubspot-analytics-for-wordpress'>enter your portal number and application domain</a> for it to work.</p></div>";
		} // end warning()

	} // end class HS_Admin

	$hs_admin = new HS_Admin();
} //endif

if ( ! class_exists( 'HS_Filter' ) ) {
	class HS_Filter {

		/*
		 * Insert the tracking code into the page
		 */
		function spool_analytics() {	
			global $wp_query;					
			$options  = get_option('HubSpotAnalyticsPP');
			
			if ( $options["portal"] != "" && $options["appdomain"] != "" ) { 
				echo "\n".'<!-- HubSpot Analytics for WordPress | http://success.hubspot.com/ -->'."\n";
				echo '<script type="text/javascript" language="javascript">'."\n";
				echo "\t".'var hs_portalid = "'.$options["portal"].'";'."\n";
				echo "\t".'var hs_salog_version = "2.00";'."\n";
				echo "\t".'var hs_ppa = "'.$options["appdomain"].'";'."\n";	
				echo "\t"."document.write(unescape(\"%3Cscript src='\" + document.location.protocol + \"\/\/\" + hs_ppa + \"/salog.js.aspx' type='text/javascript'%3E%3C/script%3E\"));"."\n";							
				echo '</script>'."\n";
				echo '<!-- End of HubSpot Analytics code -->'."\n";
				}
				
			} 
		
		
	} // class GA_Filter
} // endif
	


$gaf 		= new HS_Filter();
$options	= get_option('HubSpotAnalyticsPP');

if (!is_array($options))
	$hs_admin->set_defaults();
	
if ($options['position'] == 'footer' || $options['position'] == "")
	add_action('wp_footer', array('HS_Filter','spool_analytics'));

?>